@@ -23,11 +23,12 @@ from pydantic import SecretStr
 from pydantic import UUID4
 from pydantic.types import Path
 from ra_utils.load_settings import load_settings
+from ra_utils.job_settings import JobSettings
 
 from .models import JobFunction
 
 
-class CommonSettings(BaseSettings):
+class CommonSettings(JobSettings):
     """
     Settings common to both the SD importer and SD-changed-at
     """
@@ -48,7 +49,6 @@ class CommonSettings(BaseSettings):
     cpr_uuid_map_path: str = (
         "/opt/dipex/os2mo-data-import-and-export/settings/cpr_uuid_map.csv"
     )
-    cache_folder_path: str = "/opt/dipex/os2mo-data-import-and-export/tmp/"
 
 
 def gen_json_file_settings_func(settings_class: Type[CommonSettings]):
@@ -116,7 +116,6 @@ class ImporterSettings(CommonSettings):
     sd_no_salary_minimum_id: Optional[int] = None
     sd_skip_employment_types: List[str] = []
     sd_skip_job_functions: List[str] = []
-    sd_terminate_engagement_with_to_only: bool = True
     sd_use_ad_integration: bool = True
 
     class Config:
@@ -150,12 +149,8 @@ class ChangedAtSettings(CommonSettings):
 
     sd_read_forced_uuids: bool = True
     sd_skip_job_functions: List[str] = []
-    sd_terminate_engagement_with_to_only: bool = True
     sd_update_primary_engagement: bool = True
     sd_use_ad_integration: bool = True
-    sd_log_file: Path = Path("mo_integrations.log")
-
-    sentry_dsn: Optional[str] = None
 
     class Config:
         extra = Extra.forbid
