@@ -1,5 +1,6 @@
 import codecs
 import csv
+import logging
 import os
 import warnings
 from abc import ABC
@@ -27,6 +28,8 @@ from ra_utils.apply import apply
 
 T = TypeVar("T")
 
+logger = logging.getLogger(__name__)
+
 
 class FileSet(ABC):
     def __init__(self):
@@ -249,9 +252,14 @@ def parse_filenames(
 
     filtered_names = filter(lambda x: x.startswith(prefix), filenames)
     parsed_names = map(parse_filepath, filtered_names)
-    # Only use files that are newer than last import
+    # Only use files that are newer than last import, as agreed with Jesper Norup
+    fileset = get_fileset_implementation()
     new_files = filter(
-        apply(lambda filepath, filedate: filedate > last_import), parsed_names
+        apply(
+            lambda filepath, filedate: fileset.get_modified_datetime(filepath)
+            > last_import
+        ),
+        parsed_names,
     )
     sorted_filenames = sorted(new_files, key=itemgetter(1))
     return sorted_filenames
@@ -271,7 +279,7 @@ def parse_csv(lines: List[str], model: BaseModel) -> List[BaseModel]:
 
 def read_csv(filename: str, model: T) -> List[T]:
     """Read CSV file from FTP into list of model objects"""
-    print(f"Processing {filename}")
+    logger.info("Processing %s", filename)
     fileset = get_fileset_implementation()
     lines = fileset.read_file(filename)
     return parse_csv(lines, model)  # type: ignore
