@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+import copy
 import json
 import logging
 import random
@@ -410,6 +411,10 @@ class ADWriter(AD):
         return self.all_settings["primary_write"]
 
     def _wait_for_replication(self, sam):
+        # This method is only used by `ADWriter.create_user` (and only if called with
+        # `create_manager=True`.) It is questionable whether `_wait_for_replication`
+        # serves any real purpose, and we should consider removing it.
+
         t_start = time.time()
         logger.debug("Wait for replication of {}".format(sam))
         if not self.all_settings["global"]["servers"]:
@@ -919,9 +924,7 @@ class ADWriter(AD):
                     mo_values["manager_cpr"], ad_dump=ad_dump
                 )
             except CprNotFoundInADException:
-                logger.warning(
-                    "could not find manager by cpr %r", mo_values.get("manager_cpr")
-                )
+                logger.warning("could not find manager by cpr")
             else:
                 manager_distinguished_name = manager_ad_user["DistinguishedName"]
                 if ad_user["manager"] != manager_distinguished_name:
@@ -1087,80 +1090,53 @@ class ADWriter(AD):
         return path_argument
 
     def _check_if_ad_user_exists(self, sam_account_name, cpr):
-        existing_sam = self.get_from_ad(user=sam_account_name)
-        existing_cpr = self.get_from_ad(cpr=cpr)
-        if existing_sam:
+        if sam_account_name and self.get_from_ad(user=sam_account_name):
             logger.error("SamAccount already in use: {}".format(sam_account_name))
             raise SamAccountNameNotUnique(sam_account_name)
-        if existing_cpr:
-            logger.error("cpr already in use: {}".format(cpr))
-            raise CprNotNotUnique(cpr)
+        if cpr and self.get_from_ad(cpr=cpr):
+            logger.error(f"cpr already in use: {cpr[:6]}-xxxx")
+            raise CprNotNotUnique()
 
-    def add_ad_to_user_it_systems(self, username):
-        # TODO: We need a function to write the SamAccount to the user's
-        # IT-systems. This is most likely most elegantly done by importing
-        # the AD->MO sync tool
-        pass
+    def _get_enable_user_cmd(self, username: str, enable: bool) -> str:
+        # Hack: copy the settings and mutate `template_to_ad_fields` in the copy.
+        # This enables us to use a different set of field templates when enabling and
+        # disabling AD users.
+        settings = copy.deepcopy(self.settings)
+        template_to_ad_fields = {"Enabled": "$true" if enable else "$false"}
+        if enable is False:
+            # Read an additional field mapping which is only to be used when disabling
+            # AD users.
+            template_to_ad_fields_when_disable = settings["primary_write"].get(
+                "template_to_ad_fields_when_disable", {}
+            )
+            template_to_ad_fields.update(template_to_ad_fields_when_disable)
+        settings["primary_write"]["template_to_ad_fields"] = template_to_ad_fields
 
-    def set_user_password(self, username, password):
-        """
-        Set a password for a user.
-        :param username: SamAccountName for the user.
-        :param password: The password to assign to the user.
-        :return: True if success, otherwise False
-        """
-
-        format_rules = {"username": username, "password": password}
-        ps_script = self._build_ps(ad_templates.set_password_template, format_rules)
-        response = self._run_ps_script(ps_script)
-        if not response:
-            return (True, "Password updated")
-        else:
-            msg = "Failed to set password!: {}".format(response)
-            logger.error(msg)
-            return (False, msg)
+        # Render the PowerShell command to enable or disable an AD user
+        cmd = template_powershell(
+            cmd="Set-ADUser",
+            context={
+                "user_sam": username,
+                # Available for the template rendering.
+                "now": datetime.now(),
+                # Required by `template_powershell`, but not actually used.
+                "mo_values": {"level2orgunit": None, "location": None},
+            },
+            settings=settings,
+        )
+        cmd = self._build_user_credential() + self.remove_redundant(cmd)
+        return cmd
 
     def enable_user(self, username, enable=True):
         """
         Enable or disable an AD account.
         :param username: SamAccountName of the account to be enabled or disabled
-        :param enable: If True enable account, if False, disbale account
+        :param enable: If True enable account, if False, disable account
         """
-
-        logger.info("Enable account: {}".format(enable))
-        format_rules = {"username": username}
-        if enable:
-            ps_script = self._build_ps(ad_templates.enable_user_template, format_rules)
-        else:
-            ps_script = self._build_ps(ad_templates.disable_user_template, format_rules)
-
-        response = self._run_ps_script(ps_script)
-        if not response:
-            return (True, "Account enabled or disabled")
-        else:
-            msg = "Failed to update account!: {}".format(response)
-            logger.error(msg)
-            return (False, msg)
-
-    def delete_user(self, username):
-        """
-        Delete an AD account. Only to be used for service purpose, actual
-        AD integration should never delete a user, but only mark it for
-        deletetion.
-        :param username: SamAccountName of the account to be deleted
-        """
-        format_rules = {"username": username}
-        ps_script = self._build_ps(
-            ad_templates.delete_user_template, format_rules=format_rules
-        )
-
-        response = self._run_ps_script(ps_script)
-        # TODO: Should we make a read to confirm the user is gone?
-        if not response:
-            return (True, "User deleted")
-        else:
-            logger.error("Failed to delete account!: {}".format(response))
-            return (False, "Failed to delete")
+        cmd = self._get_enable_user_cmd(username, enable)
+        response = self._run_ps_script(cmd)  # raises `CommandFailure` if PS fails
+        if response == {}:
+            return True, "enabled AD user" if enable else "disabled AD user"
 
 
 @click.command()
@@ -1182,7 +1158,6 @@ class ADWriter(AD):
     type=click.UUID,
     help="Show mo-values for the user",
 )
-@optgroup.option("--delete-user")
 @optgroup.option("--read-ad-information")
 @optgroup.option("--add-manager-to-user", nargs=2, type=str)
 @click.option("--ignore-occupied-names", is_flag=True, default=False)
@@ -1212,11 +1187,6 @@ def cli(**args):
         status = ad_writer.sync_user(args["sync_user"])
         print(status[1])
 
-    if args.get("delete_user"):
-        print("Deleting user:")
-        status = ad_writer.delete_user(args["delete_user"])
-        print(status[1])
-
     if args.get("read_ad_information"):
         print("AD information on user:")
         sam = args["read_ad_information"]
